@@ -7,7 +7,7 @@ exports.countries = {
 
 	zone_countries : function (test) {
 
-		test.deepEqual(tz.zone('Africa/Abidjan').countries(), ["BF","CI","GM","GN","ML","MR","SH","SL","SN","TG"]);
+		test.deepEqual(tz.zone("Africa/Abidjan").countries(), ["BF","CI","GH","GM","GN","IS","ML","MR","SH","SL","SN","TG"]);
 		test.deepEqual(tz.zone('Africa/Accra').countries(), ["GH"]);
 		test.deepEqual(tz.zone('Africa/Addis_Ababa').countries(), ["ET"]);
 		test.deepEqual(tz.zone('Africa/Algiers').countries(), ["DZ"]);
@@ -107,7 +107,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Costa_Rica').countries(), ["CR"]);
 		test.deepEqual(tz.zone('America/Creston').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Cuiaba').countries(), ["BR"]);
-		test.deepEqual(tz.zone('America/Curacao').countries(), ["AW","BQ","CW","SX"]);
+		test.deepEqual(tz.zone('America/Curacao').countries(), ["CW"]);
 		test.deepEqual(tz.zone('America/Danmarkshavn').countries(), ["GL"]);
 		test.deepEqual(tz.zone('America/Dawson').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Dawson_Creek').countries(), ["CA"]);
@@ -183,15 +183,15 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/North_Dakota/Center').countries(), ["US"]);
 		test.deepEqual(tz.zone('America/North_Dakota/New_Salem').countries(), ["US"]);
 		test.deepEqual(tz.zone('America/Ojinaga').countries(), ["MX"]);
-		test.deepEqual(tz.zone('America/Panama').countries(), ["KY","PA"]);
+		test.deepEqual(tz.zone('America/Panama').countries(), ["CA","KY","PA"]);
 		test.deepEqual(tz.zone('America/Pangnirtung').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Paramaribo').countries(), ["SR"]);
-		test.deepEqual(tz.zone('America/Phoenix').countries(), ["US"]);
+		test.deepEqual(tz.zone('America/Phoenix').countries(), ["CA","US"]);
 		test.deepEqual(tz.zone('America/Port-au-Prince').countries(), ["HT"]);
-		test.deepEqual(tz.zone('America/Port_of_Spain').countries(), ["AG","AI","BL","DM","GD","GP","KN","LC","MF","MS","TT","VC","VG","VI"]);
+		test.deepEqual(tz.zone('America/Port_of_Spain').countries(), ["TT"]);
 		test.deepEqual(tz.zone('America/Porto_Acre').countries(), []);
 		test.deepEqual(tz.zone('America/Porto_Velho').countries(), ["BR"]);
-		test.deepEqual(tz.zone('America/Puerto_Rico').countries(), ["PR"]);
+		test.deepEqual(tz.zone("America/Puerto_Rico").countries(), ["AG","AI","AW","BL","BQ","CA","CW","DM","GD","GP","KN","LC","MF","MS","PR","SX","TT","VC","VG","VI"]);
 		test.deepEqual(tz.zone('America/Punta_Arenas').countries(), ["CL"]);
 		test.deepEqual(tz.zone('America/Rainy_River').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Rankin_Inlet').countries(), ["CA"]);
@@ -219,7 +219,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('America/Thule').countries(), ["GL"]);
 		test.deepEqual(tz.zone('America/Thunder_Bay').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Tijuana').countries(), ["MX"]);
-		test.deepEqual(tz.zone('America/Toronto').countries(), ["CA"]);
+		test.deepEqual(tz.zone('America/Toronto').countries(), ["BS","CA"]);
 		test.deepEqual(tz.zone('America/Tortola').countries(), ["VG"]);
 		test.deepEqual(tz.zone('America/Vancouver').countries(), ["CA"]);
 		test.deepEqual(tz.zone('America/Virgin').countries(), []);
@@ -252,7 +252,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('Asia/Baghdad').countries(), ["IQ"]);
 		test.deepEqual(tz.zone('Asia/Bahrain').countries(), ["BH"]);
 		test.deepEqual(tz.zone('Asia/Baku').countries(), ["AZ"]);
-		test.deepEqual(tz.zone('Asia/Bangkok').countries(), ["KH","LA","TH","VN"]);
+		test.deepEqual(tz.zone('Asia/Bangkok').countries(), ["CX","KH","LA","TH","VN"]);
 		test.deepEqual(tz.zone('Asia/Barnaul').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Beirut').countries(), ["LB"]);
 		test.deepEqual(tz.zone('Asia/Bishkek').countries(), ["KG"]);
@@ -267,7 +267,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('Asia/Damascus').countries(), ["SY"]);
 		test.deepEqual(tz.zone('Asia/Dhaka').countries(), ["BD"]);
 		test.deepEqual(tz.zone('Asia/Dili').countries(), ["TL"]);
-		test.deepEqual(tz.zone('Asia/Dubai').countries(), ["AE","OM"]);
+		test.deepEqual(tz.zone('Asia/Dubai').countries(), ["AE","OM","RE","SC","TF"]);
 		test.deepEqual(tz.zone('Asia/Dushanbe').countries(), ["TJ"]);
 		test.deepEqual(tz.zone('Asia/Famagusta').countries(), ["CY"]);
 		test.deepEqual(tz.zone('Asia/Gaza').countries(), ["PS"]);
@@ -291,7 +291,7 @@ exports.countries = {
 		test.deepEqual(tz.zone('Asia/Kolkata').countries(), ["IN"]);
 		test.deepEqual(tz.zone('Asia/Krasnoyarsk').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Kuala_Lumpur').countries(), ["MY"]);
-		test.deepEqual(tz.zone('Asia/Kuching').countries(), ["MY"]);
+		test.deepEqual(tz.zone('Asia/Kuching').countries(), ["BN","MY"]);
 		test.deepEqual(tz.zone('Asia/Kuwait').countries(), ["KW"]);
 		test.deepEqual(tz.zone('Asia/Macao').countries(), []);
 		test.deepEqual(tz.zone('Asia/Macau').countries(), ["MO"]);
@@ -311,13 +311,13 @@ exports.countries = {
 		test.deepEqual(tz.zone('Asia/Qostanay').countries(), ["KZ"]);
 		test.deepEqual(tz.zone('Asia/Qyzylorda').countries(), ["KZ"]);
 		test.deepEqual(tz.zone('Asia/Rangoon').countries(), []);
-		test.deepEqual(tz.zone('Asia/Riyadh').countries(), ["KW","SA","YE"]);
+		test.deepEqual(tz.zone('Asia/Riyadh').countries(), ["AQ","KW","SA","YE"]);
 		test.deepEqual(tz.zone('Asia/Saigon').countries(), []);
 		test.deepEqual(tz.zone('Asia/Sakhalin').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Samarkand').countries(), ["UZ"]);
 		test.deepEqual(tz.zone('Asia/Seoul').countries(), ["KR"]);
 		test.deepEqual(tz.zone('Asia/Shanghai').countries(), ["CN"]);
-		test.deepEqual(tz.zone('Asia/Singapore').countries(), ["SG"]);
+		test.deepEqual(tz.zone('Asia/Singapore').countries(), ["MY","SG"]);
 		test.deepEqual(tz.zone('Asia/Srednekolymsk').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Taipei').countries(), ["TW"]);
 		test.deepEqual(tz.zone('Asia/Tashkent').countries(), ["UZ"]);
@@ -331,12 +331,12 @@ exports.countries = {
 		test.deepEqual(tz.zone('Asia/Ujung_Pandang').countries(), []);
 		test.deepEqual(tz.zone('Asia/Ulaanbaatar').countries(), ["MN"]);
 		test.deepEqual(tz.zone('Asia/Ulan_Bator').countries(), []);
-		test.deepEqual(tz.zone('Asia/Urumqi').countries(), ["CN"]);
+		test.deepEqual(tz.zone('Asia/Urumqi').countries(), ["AQ","CN"]);
 		test.deepEqual(tz.zone('Asia/Ust-Nera').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Vientiane').countries(), ["LA"]);
 		test.deepEqual(tz.zone('Asia/Vladivostok').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Yakutsk').countries(), ["RU"]);
-		test.deepEqual(tz.zone('Asia/Yangon').countries(), ["MM"]);
+		test.deepEqual(tz.zone('Asia/Yangon').countries(), ["CC","MM"]);
 		test.deepEqual(tz.zone('Asia/Yekaterinburg').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Asia/Yerevan').countries(), ["AM"]);
 		test.deepEqual(tz.zone('Atlantic/Azores').countries(), ["PT"]);
@@ -437,9 +437,9 @@ exports.countries = {
 		test.deepEqual(tz.zone('Europe/Athens').countries(), ["GR"]);
 		test.deepEqual(tz.zone('Europe/Belfast').countries(), []);
 		test.deepEqual(tz.zone('Europe/Belgrade').countries(), ["BA","HR","ME","MK","RS","SI"]);
-		test.deepEqual(tz.zone('Europe/Berlin').countries(), ["DE"]);
+		test.deepEqual(tz.zone('Europe/Berlin').countries(), ["DE","DK","NO","SE","SJ"]);
 		test.deepEqual(tz.zone('Europe/Bratislava').countries(), ["SK"]);
-		test.deepEqual(tz.zone('Europe/Brussels').countries(), ["BE"]);
+		test.deepEqual(tz.zone('Europe/Brussels').countries(), ["BE","LU","NL"]);
 		test.deepEqual(tz.zone('Europe/Bucharest').countries(), ["RO"]);
 		test.deepEqual(tz.zone('Europe/Budapest').countries(), ["HU"]);
 		test.deepEqual(tz.zone('Europe/Busingen').countries(), ["DE"]);
@@ -453,7 +453,8 @@ exports.countries = {
 		test.deepEqual(tz.zone('Europe/Istanbul').countries(), ["TR"]);
 		test.deepEqual(tz.zone('Europe/Jersey').countries(), ["JE"]);
 		test.deepEqual(tz.zone('Europe/Kaliningrad').countries(), ["RU"]);
-		test.deepEqual(tz.zone('Europe/Kiev').countries(), ["UA"]);
+		test.deepEqual(tz.zone('Europe/Kiev').countries(), []);
+		test.deepEqual(tz.zone('Europe/Kyiv').countries(), ["UA"]);
 		test.deepEqual(tz.zone('Europe/Kirov').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Europe/Lisbon').countries(), ["PT"]);
 		test.deepEqual(tz.zone('Europe/Ljubljana').countries(), ["SI"]);
@@ -466,8 +467,8 @@ exports.countries = {
 		test.deepEqual(tz.zone('Europe/Monaco').countries(), ["MC"]);
 		test.deepEqual(tz.zone('Europe/Moscow').countries(), ["RU"]);
 		test.deepEqual(tz.zone('Europe/Nicosia').countries(), []);
-		test.deepEqual(tz.zone('Europe/Oslo').countries(), ["NO","SJ"]);
-		test.deepEqual(tz.zone('Europe/Paris').countries(), ["FR"]);
+		test.deepEqual(tz.zone('Europe/Oslo').countries(), ["NO"]);
+		test.deepEqual(tz.zone('Europe/Paris').countries(), ["FR","MC"]);
 		test.deepEqual(tz.zone('Europe/Podgorica').countries(), ["ME"]);
 		test.deepEqual(tz.zone('Europe/Prague').countries(), ["CZ","SK"]);
 		test.deepEqual(tz.zone('Europe/Riga').countries(), ["LV"]);
@@ -511,10 +512,10 @@ exports.countries = {
 		test.deepEqual(tz.zone('Indian/Comoro').countries(), ["KM"]);
 		test.deepEqual(tz.zone('Indian/Kerguelen').countries(), ["TF"]);
 		test.deepEqual(tz.zone('Indian/Mahe').countries(), ["SC"]);
-		test.deepEqual(tz.zone('Indian/Maldives').countries(), ["MV"]);
+		test.deepEqual(tz.zone('Indian/Maldives').countries(), ["MV","TF"]);
 		test.deepEqual(tz.zone('Indian/Mauritius').countries(), ["MU"]);
 		test.deepEqual(tz.zone('Indian/Mayotte').countries(), ["YT"]);
-		test.deepEqual(tz.zone('Indian/Reunion').countries(), ["RE","TF"]);
+		test.deepEqual(tz.zone('Indian/Reunion').countries(), ["RE"]);
 		test.deepEqual(tz.zone('Iran').countries(), []);
 		test.deepEqual(tz.zone('Israel').countries(), []);
 		test.deepEqual(tz.zone('Jamaica').countries(), []);
@@ -539,13 +540,13 @@ exports.countries = {
 		test.deepEqual(tz.zone('Pacific/Chuuk').countries(), ["FM"]);
 		test.deepEqual(tz.zone('Pacific/Easter').countries(), ["CL"]);
 		test.deepEqual(tz.zone('Pacific/Efate').countries(), ["VU"]);
-		test.deepEqual(tz.zone('Pacific/Enderbury').countries(), ["KI"]);
+		test.deepEqual(tz.zone('Pacific/Enderbury').countries(), []);
 		test.deepEqual(tz.zone('Pacific/Fakaofo').countries(), ["TK"]);
 		test.deepEqual(tz.zone('Pacific/Fiji').countries(), ["FJ"]);
 		test.deepEqual(tz.zone('Pacific/Funafuti').countries(), ["TV"]);
 		test.deepEqual(tz.zone('Pacific/Galapagos').countries(), ["EC"]);
 		test.deepEqual(tz.zone('Pacific/Gambier').countries(), ["PF"]);
-		test.deepEqual(tz.zone('Pacific/Guadalcanal').countries(), ["SB"]);
+		test.deepEqual(tz.zone('Pacific/Guadalcanal').countries(), ["FM","SB"]);
 		test.deepEqual(tz.zone('Pacific/Guam').countries(), ["GU","MP"]);
 		test.deepEqual(tz.zone('Pacific/Honolulu').countries(), ["UM","US"]);
 		test.deepEqual(tz.zone('Pacific/Johnston').countries(), []);
@@ -564,12 +565,12 @@ exports.countries = {
 		test.deepEqual(tz.zone('Pacific/Pitcairn').countries(), ["PN"]);
 		test.deepEqual(tz.zone('Pacific/Pohnpei').countries(), ["FM"]);
 		test.deepEqual(tz.zone('Pacific/Ponape').countries(), []);
-		test.deepEqual(tz.zone('Pacific/Port_Moresby').countries(), ["PG"]);
+		test.deepEqual(tz.zone('Pacific/Port_Moresby').countries(), ["AQ","FM","PG"]);
 		test.deepEqual(tz.zone('Pacific/Rarotonga').countries(), ["CK"]);
 		test.deepEqual(tz.zone('Pacific/Saipan').countries(), ["MP"]);
 		test.deepEqual(tz.zone('Pacific/Samoa').countries(), []);
 		test.deepEqual(tz.zone('Pacific/Tahiti').countries(), ["PF"]);
-		test.deepEqual(tz.zone('Pacific/Tarawa').countries(), ["KI"]);
+		test.deepEqual(tz.zone('Pacific/Tarawa').countries(), ["KI","MH","TV","UM","WF"]);
 		test.deepEqual(tz.zone('Pacific/Tongatapu').countries(), ["TO"]);
 		test.deepEqual(tz.zone('Pacific/Truk').countries(), []);
 		test.deepEqual(tz.zone('Pacific/Wake').countries(), ["UM"]);
@@ -608,17 +609,17 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("AD"), ["Europe/Andorra"]);
 		test.deepEqual(tz.zonesForCountry("AE"), ["Asia/Dubai"]);
 		test.deepEqual(tz.zonesForCountry("AF"), ["Asia/Kabul"]);
-		test.deepEqual(tz.zonesForCountry("AG"), ["America/Antigua","America/Port_of_Spain"]);
-		test.deepEqual(tz.zonesForCountry("AI"), ["America/Anguilla","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("AG"), ["America/Antigua","America/Puerto_Rico"]);
+		test.deepEqual(tz.zonesForCountry("AI"), ["America/Anguilla","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("AL"), ["Europe/Tirane"]);
 		test.deepEqual(tz.zonesForCountry("AM"), ["Asia/Yerevan"]);
 		test.deepEqual(tz.zonesForCountry("AO"), ["Africa/Lagos","Africa/Luanda"]);
-		test.deepEqual(tz.zonesForCountry("AQ"), ["Antarctica/Casey","Antarctica/Davis","Antarctica/DumontDUrville","Antarctica/Mawson","Antarctica/McMurdo","Antarctica/Palmer","Antarctica/Rothera","Antarctica/Syowa","Antarctica/Troll","Antarctica/Vostok","Pacific/Auckland"]);
+		test.deepEqual(tz.zonesForCountry("AQ"), ["Antarctica/Casey","Antarctica/Davis","Antarctica/DumontDUrville","Antarctica/Mawson","Antarctica/McMurdo","Antarctica/Palmer","Antarctica/Rothera","Antarctica/Syowa","Antarctica/Troll","Antarctica/Vostok","Asia/Riyadh","Asia/Urumqi","Pacific/Auckland","Pacific/Port_Moresby"]);
 		test.deepEqual(tz.zonesForCountry("AR"), ["America/Argentina/Buenos_Aires","America/Argentina/Catamarca","America/Argentina/Cordoba","America/Argentina/Jujuy","America/Argentina/La_Rioja","America/Argentina/Mendoza","America/Argentina/Rio_Gallegos","America/Argentina/Salta","America/Argentina/San_Juan","America/Argentina/San_Luis","America/Argentina/Tucuman","America/Argentina/Ushuaia"]);
 		test.deepEqual(tz.zonesForCountry("AS"), ["Pacific/Pago_Pago"]);
 		test.deepEqual(tz.zonesForCountry("AT"), ["Europe/Vienna"]);
 		test.deepEqual(tz.zonesForCountry("AU"), ["Antarctica/Macquarie","Australia/Adelaide","Australia/Brisbane","Australia/Broken_Hill","Australia/Darwin","Australia/Eucla","Australia/Hobart","Australia/Lindeman","Australia/Lord_Howe","Australia/Melbourne","Australia/Perth","Australia/Sydney"]);
-		test.deepEqual(tz.zonesForCountry("AW"), ["America/Aruba","America/Curacao"]);
+		test.deepEqual(tz.zonesForCountry("AW"), ["America/Aruba","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("AX"), ["Europe/Helsinki","Europe/Mariehamn"]);
 		test.deepEqual(tz.zonesForCountry("AZ"), ["Asia/Baku"]);
 		test.deepEqual(tz.zonesForCountry("BA"), ["Europe/Belgrade","Europe/Sarajevo"]);
@@ -630,19 +631,19 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("BH"), ["Asia/Bahrain","Asia/Qatar"]);
 		test.deepEqual(tz.zonesForCountry("BI"), ["Africa/Bujumbura","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("BJ"), ["Africa/Lagos","Africa/Porto-Novo"]);
-		test.deepEqual(tz.zonesForCountry("BL"), ["America/Port_of_Spain","America/St_Barthelemy"]);
+		test.deepEqual(tz.zonesForCountry("BL"), ["America/Puerto_Rico","America/St_Barthelemy"]);
 		test.deepEqual(tz.zonesForCountry("BM"), ["Atlantic/Bermuda"]);
-		test.deepEqual(tz.zonesForCountry("BN"), ["Asia/Brunei"]);
+		test.deepEqual(tz.zonesForCountry("BN"), ["Asia/Brunei","Asia/Kuching"]);
 		test.deepEqual(tz.zonesForCountry("BO"), ["America/La_Paz"]);
-		test.deepEqual(tz.zonesForCountry("BQ"), ["America/Curacao","America/Kralendijk"]);
+		test.deepEqual(tz.zonesForCountry("BQ"), ["America/Kralendijk","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("BR"), ["America/Araguaina","America/Bahia","America/Belem","America/Boa_Vista","America/Campo_Grande","America/Cuiaba","America/Eirunepe","America/Fortaleza","America/Maceio","America/Manaus","America/Noronha","America/Porto_Velho","America/Recife","America/Rio_Branco","America/Santarem","America/Sao_Paulo"]);
-		test.deepEqual(tz.zonesForCountry("BS"), ["America/Nassau"]);
+		test.deepEqual(tz.zonesForCountry("BS"), ["America/Nassau","America/Toronto"]);
 		test.deepEqual(tz.zonesForCountry("BT"), ["Asia/Thimphu"]);
 		test.deepEqual(tz.zonesForCountry("BW"), ["Africa/Gaborone","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("BY"), ["Europe/Minsk"]);
 		test.deepEqual(tz.zonesForCountry("BZ"), ["America/Belize"]);
-		test.deepEqual(tz.zonesForCountry("CA"), ["America/Atikokan","America/Blanc-Sablon","America/Cambridge_Bay","America/Creston","America/Dawson","America/Dawson_Creek","America/Edmonton","America/Fort_Nelson","America/Glace_Bay","America/Goose_Bay","America/Halifax","America/Inuvik","America/Iqaluit","America/Moncton","America/Nipigon","America/Pangnirtung","America/Rainy_River","America/Rankin_Inlet","America/Regina","America/Resolute","America/St_Johns","America/Swift_Current","America/Thunder_Bay","America/Toronto","America/Vancouver","America/Whitehorse","America/Winnipeg","America/Yellowknife"]);
-		test.deepEqual(tz.zonesForCountry("CC"), ["Indian/Cocos"]);
+		test.deepEqual(tz.zonesForCountry("CA"), ["America/Atikokan","America/Blanc-Sablon","America/Cambridge_Bay","America/Creston","America/Dawson","America/Dawson_Creek","America/Edmonton","America/Fort_Nelson","America/Glace_Bay","America/Goose_Bay","America/Halifax","America/Inuvik","America/Iqaluit","America/Moncton","America/Nipigon","America/Panama","America/Pangnirtung","America/Phoenix","America/Puerto_Rico","America/Rainy_River","America/Rankin_Inlet","America/Regina","America/Resolute","America/St_Johns","America/Swift_Current","America/Thunder_Bay","America/Toronto","America/Vancouver","America/Whitehorse","America/Winnipeg","America/Yellowknife"]);
+		test.deepEqual(tz.zonesForCountry("CC"), ["Asia/Yangon","Indian/Cocos"]);
 		test.deepEqual(tz.zonesForCountry("CD"), ["Africa/Kinshasa","Africa/Lagos","Africa/Lubumbashi","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("CF"), ["Africa/Bangui","Africa/Lagos"]);
 		test.deepEqual(tz.zonesForCountry("CG"), ["Africa/Brazzaville","Africa/Lagos"]);
@@ -656,14 +657,14 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("CR"), ["America/Costa_Rica"]);
 		test.deepEqual(tz.zonesForCountry("CU"), ["America/Havana"]);
 		test.deepEqual(tz.zonesForCountry("CV"), ["Atlantic/Cape_Verde"]);
-		test.deepEqual(tz.zonesForCountry("CW"), ["America/Curacao"]);
-		test.deepEqual(tz.zonesForCountry("CX"), ["Indian/Christmas"]);
+		test.deepEqual(tz.zonesForCountry("CW"), ["America/Curacao","America/Puerto_Rico"]);
+		test.deepEqual(tz.zonesForCountry("CX"), ["Asia/Bangkok","Indian/Christmas"]);
 		test.deepEqual(tz.zonesForCountry("CY"), ["Asia/Famagusta","Asia/Nicosia"]);
 		test.deepEqual(tz.zonesForCountry("CZ"), ["Europe/Prague"]);
 		test.deepEqual(tz.zonesForCountry("DE"), ["Europe/Berlin","Europe/Busingen","Europe/Zurich"]);
 		test.deepEqual(tz.zonesForCountry("DJ"), ["Africa/Djibouti","Africa/Nairobi"]);
-		test.deepEqual(tz.zonesForCountry("DK"), ["Europe/Copenhagen"]);
-		test.deepEqual(tz.zonesForCountry("DM"), ["America/Dominica","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("DK"), ["Europe/Berlin","Europe/Copenhagen"]);
+		test.deepEqual(tz.zonesForCountry("DM"), ["America/Dominica","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("DO"), ["America/Santo_Domingo"]);
 		test.deepEqual(tz.zonesForCountry("DZ"), ["Africa/Algiers"]);
 		test.deepEqual(tz.zonesForCountry("EC"), ["America/Guayaquil","Pacific/Galapagos"]);
@@ -676,21 +677,21 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("FI"), ["Europe/Helsinki"]);
 		test.deepEqual(tz.zonesForCountry("FJ"), ["Pacific/Fiji"]);
 		test.deepEqual(tz.zonesForCountry("FK"), ["Atlantic/Stanley"]);
-		test.deepEqual(tz.zonesForCountry("FM"), ["Pacific/Chuuk","Pacific/Kosrae","Pacific/Pohnpei"]);
+		test.deepEqual(tz.zonesForCountry("FM"), ["Pacific/Chuuk","Pacific/Guadalcanal","Pacific/Kosrae","Pacific/Pohnpei","Pacific/Port_Moresby"]);
 		test.deepEqual(tz.zonesForCountry("FO"), ["Atlantic/Faroe"]);
 		test.deepEqual(tz.zonesForCountry("FR"), ["Europe/Paris"]);
 		test.deepEqual(tz.zonesForCountry("GA"), ["Africa/Lagos","Africa/Libreville"]);
 		test.deepEqual(tz.zonesForCountry("GB"), ["Europe/London"]);
-		test.deepEqual(tz.zonesForCountry("GD"), ["America/Grenada","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("GD"), ["America/Grenada","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("GE"), ["Asia/Tbilisi"]);
 		test.deepEqual(tz.zonesForCountry("GF"), ["America/Cayenne"]);
 		test.deepEqual(tz.zonesForCountry("GG"), ["Europe/Guernsey","Europe/London"]);
-		test.deepEqual(tz.zonesForCountry("GH"), ["Africa/Accra"]);
+		test.deepEqual(tz.zonesForCountry("GH"), ["Africa/Abidjan","Africa/Accra"]);
 		test.deepEqual(tz.zonesForCountry("GI"), ["Europe/Gibraltar"]);
 		test.deepEqual(tz.zonesForCountry("GL"), ["America/Danmarkshavn","America/Nuuk","America/Scoresbysund","America/Thule"]);
 		test.deepEqual(tz.zonesForCountry("GM"), ["Africa/Abidjan","Africa/Banjul"]);
 		test.deepEqual(tz.zonesForCountry("GN"), ["Africa/Abidjan","Africa/Conakry"]);
-		test.deepEqual(tz.zonesForCountry("GP"), ["America/Guadeloupe","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("GP"), ["America/Guadeloupe","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("GQ"), ["Africa/Lagos","Africa/Malabo"]);
 		test.deepEqual(tz.zonesForCountry("GR"), ["Europe/Athens"]);
 		test.deepEqual(tz.zonesForCountry("GS"), ["Atlantic/South_Georgia"]);
@@ -711,7 +712,7 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("IO"), ["Indian/Chagos"]);
 		test.deepEqual(tz.zonesForCountry("IQ"), ["Asia/Baghdad"]);
 		test.deepEqual(tz.zonesForCountry("IR"), ["Asia/Tehran"]);
-		test.deepEqual(tz.zonesForCountry("IS"), ["Atlantic/Reykjavik"]);
+		test.deepEqual(tz.zonesForCountry("IS"), ["Africa/Abidjan","Atlantic/Reykjavik"]);
 		test.deepEqual(tz.zonesForCountry("IT"), ["Europe/Rome"]);
 		test.deepEqual(tz.zonesForCountry("JE"), ["Europe/Jersey","Europe/London"]);
 		test.deepEqual(tz.zonesForCountry("JM"), ["America/Jamaica"]);
@@ -720,9 +721,9 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("KE"), ["Africa/Nairobi"]);
 		test.deepEqual(tz.zonesForCountry("KG"), ["Asia/Bishkek"]);
 		test.deepEqual(tz.zonesForCountry("KH"), ["Asia/Bangkok","Asia/Phnom_Penh"]);
-		test.deepEqual(tz.zonesForCountry("KI"), ["Pacific/Enderbury","Pacific/Kiritimati","Pacific/Tarawa"]);
+		test.deepEqual(tz.zonesForCountry("KI"), ["Pacific/Kanton","Pacific/Kiritimati","Pacific/Tarawa"]);
 		test.deepEqual(tz.zonesForCountry("KM"), ["Africa/Nairobi","Indian/Comoro"]);
-		test.deepEqual(tz.zonesForCountry("KN"), ["America/Port_of_Spain","America/St_Kitts"]);
+		test.deepEqual(tz.zonesForCountry("KN"), ["America/Puerto_Rico","America/St_Kitts"]);
 		test.deepEqual(tz.zonesForCountry("KP"), ["Asia/Pyongyang"]);
 		test.deepEqual(tz.zonesForCountry("KR"), ["Asia/Seoul"]);
 		test.deepEqual(tz.zonesForCountry("KW"), ["Asia/Kuwait","Asia/Riyadh"]);
@@ -730,22 +731,22 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("KZ"), ["Asia/Almaty","Asia/Aqtau","Asia/Aqtobe","Asia/Atyrau","Asia/Oral","Asia/Qostanay","Asia/Qyzylorda"]);
 		test.deepEqual(tz.zonesForCountry("LA"), ["Asia/Bangkok","Asia/Vientiane"]);
 		test.deepEqual(tz.zonesForCountry("LB"), ["Asia/Beirut"]);
-		test.deepEqual(tz.zonesForCountry("LC"), ["America/Port_of_Spain","America/St_Lucia"]);
+		test.deepEqual(tz.zonesForCountry("LC"), ["America/Puerto_Rico","America/St_Lucia"]);
 		test.deepEqual(tz.zonesForCountry("LI"), ["Europe/Vaduz","Europe/Zurich"]);
 		test.deepEqual(tz.zonesForCountry("LK"), ["Asia/Colombo"]);
 		test.deepEqual(tz.zonesForCountry("LR"), ["Africa/Monrovia"]);
 		test.deepEqual(tz.zonesForCountry("LS"), ["Africa/Johannesburg","Africa/Maseru"]);
 		test.deepEqual(tz.zonesForCountry("LT"), ["Europe/Vilnius"]);
-		test.deepEqual(tz.zonesForCountry("LU"), ["Europe/Luxembourg"]);
+		test.deepEqual(tz.zonesForCountry("LU"), ["Europe/Brussels","Europe/Luxembourg"]);
 		test.deepEqual(tz.zonesForCountry("LV"), ["Europe/Riga"]);
 		test.deepEqual(tz.zonesForCountry("LY"), ["Africa/Tripoli"]);
 		test.deepEqual(tz.zonesForCountry("MA"), ["Africa/Casablanca"]);
-		test.deepEqual(tz.zonesForCountry("MC"), ["Europe/Monaco"]);
+		test.deepEqual(tz.zonesForCountry("MC"), ["Europe/Monaco","Europe/Paris"]);
 		test.deepEqual(tz.zonesForCountry("MD"), ["Europe/Chisinau"]);
 		test.deepEqual(tz.zonesForCountry("ME"), ["Europe/Belgrade","Europe/Podgorica"]);
-		test.deepEqual(tz.zonesForCountry("MF"), ["America/Marigot","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("MF"), ["America/Marigot","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("MG"), ["Africa/Nairobi","Indian/Antananarivo"]);
-		test.deepEqual(tz.zonesForCountry("MH"), ["Pacific/Kwajalein","Pacific/Majuro"]);
+		test.deepEqual(tz.zonesForCountry("MH"), ["Pacific/Kwajalein","Pacific/Majuro","Pacific/Tarawa"]);
 		test.deepEqual(tz.zonesForCountry("MK"), ["Europe/Belgrade","Europe/Skopje"]);
 		test.deepEqual(tz.zonesForCountry("ML"), ["Africa/Abidjan","Africa/Bamako"]);
 		test.deepEqual(tz.zonesForCountry("MM"), ["Asia/Yangon"]);
@@ -754,13 +755,13 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("MP"), ["Pacific/Guam","Pacific/Saipan"]);
 		test.deepEqual(tz.zonesForCountry("MQ"), ["America/Martinique"]);
 		test.deepEqual(tz.zonesForCountry("MR"), ["Africa/Abidjan","Africa/Nouakchott"]);
-		test.deepEqual(tz.zonesForCountry("MS"), ["America/Montserrat","America/Port_of_Spain"]);
+		test.deepEqual(tz.zonesForCountry("MS"), ["America/Montserrat","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("MT"), ["Europe/Malta"]);
 		test.deepEqual(tz.zonesForCountry("MU"), ["Indian/Mauritius"]);
 		test.deepEqual(tz.zonesForCountry("MV"), ["Indian/Maldives"]);
 		test.deepEqual(tz.zonesForCountry("MW"), ["Africa/Blantyre","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("MX"), ["America/Bahia_Banderas","America/Cancun","America/Chihuahua","America/Hermosillo","America/Matamoros","America/Mazatlan","America/Merida","America/Mexico_City","America/Monterrey","America/Ojinaga","America/Tijuana"]);
-		test.deepEqual(tz.zonesForCountry("MY"), ["Asia/Kuala_Lumpur","Asia/Kuching"]);
+		test.deepEqual(tz.zonesForCountry("MY"), ["Asia/Kuala_Lumpur","Asia/Kuching","Asia/Singapore"]);
 		test.deepEqual(tz.zonesForCountry("MZ"), ["Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("NA"), ["Africa/Windhoek"]);
 		test.deepEqual(tz.zonesForCountry("NC"), ["Pacific/Noumea"]);
@@ -768,8 +769,8 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("NF"), ["Pacific/Norfolk"]);
 		test.deepEqual(tz.zonesForCountry("NG"), ["Africa/Lagos"]);
 		test.deepEqual(tz.zonesForCountry("NI"), ["America/Managua"]);
-		test.deepEqual(tz.zonesForCountry("NL"), ["Europe/Amsterdam"]);
-		test.deepEqual(tz.zonesForCountry("NO"), ["Europe/Oslo"]);
+		test.deepEqual(tz.zonesForCountry("NL"), ["Europe/Amsterdam","Europe/Brussels"]);
+		test.deepEqual(tz.zonesForCountry("NO"), ["Europe/Berlin","Europe/Oslo"]);
 		test.deepEqual(tz.zonesForCountry("NP"), ["Asia/Kathmandu"]);
 		test.deepEqual(tz.zonesForCountry("NR"), ["Pacific/Nauru"]);
 		test.deepEqual(tz.zonesForCountry("NU"), ["Pacific/Niue"]);
@@ -790,20 +791,20 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("PW"), ["Pacific/Palau"]);
 		test.deepEqual(tz.zonesForCountry("PY"), ["America/Asuncion"]);
 		test.deepEqual(tz.zonesForCountry("QA"), ["Asia/Qatar"]);
-		test.deepEqual(tz.zonesForCountry("RE"), ["Indian/Reunion"]);
+		test.deepEqual(tz.zonesForCountry("RE"), ["Asia/Dubai","Indian/Reunion"]);
 		test.deepEqual(tz.zonesForCountry("RO"), ["Europe/Bucharest"]);
 		test.deepEqual(tz.zonesForCountry("RS"), ["Europe/Belgrade"]);
 		test.deepEqual(tz.zonesForCountry("RU"), ["Asia/Anadyr","Asia/Barnaul","Asia/Chita","Asia/Irkutsk","Asia/Kamchatka","Asia/Khandyga","Asia/Krasnoyarsk","Asia/Magadan","Asia/Novokuznetsk","Asia/Novosibirsk","Asia/Omsk","Asia/Sakhalin","Asia/Srednekolymsk","Asia/Tomsk","Asia/Ust-Nera","Asia/Vladivostok","Asia/Yakutsk","Asia/Yekaterinburg","Europe/Astrakhan","Europe/Kaliningrad","Europe/Kirov","Europe/Moscow","Europe/Samara","Europe/Saratov","Europe/Simferopol","Europe/Ulyanovsk","Europe/Volgograd"]);
 		test.deepEqual(tz.zonesForCountry("RW"), ["Africa/Kigali","Africa/Maputo"]);
 		test.deepEqual(tz.zonesForCountry("SA"), ["Asia/Riyadh"]);
 		test.deepEqual(tz.zonesForCountry("SB"), ["Pacific/Guadalcanal"]);
-		test.deepEqual(tz.zonesForCountry("SC"), ["Indian/Mahe"]);
+		test.deepEqual(tz.zonesForCountry("SC"), ["Asia/Dubai","Indian/Mahe"]);
 		test.deepEqual(tz.zonesForCountry("SD"), ["Africa/Khartoum"]);
-		test.deepEqual(tz.zonesForCountry("SE"), ["Europe/Stockholm"]);
+		test.deepEqual(tz.zonesForCountry("SE"), ["Europe/Berlin","Europe/Stockholm"]);
 		test.deepEqual(tz.zonesForCountry("SG"), ["Asia/Singapore"]);
 		test.deepEqual(tz.zonesForCountry("SH"), ["Africa/Abidjan","Atlantic/St_Helena"]);
 		test.deepEqual(tz.zonesForCountry("SI"), ["Europe/Belgrade","Europe/Ljubljana"]);
-		test.deepEqual(tz.zonesForCountry("SJ"), ["Arctic/Longyearbyen","Europe/Oslo"]);
+		test.deepEqual(tz.zonesForCountry("SJ"), ["Arctic/Longyearbyen","Europe/Berlin"]);
 		test.deepEqual(tz.zonesForCountry("SK"), ["Europe/Bratislava","Europe/Prague"]);
 		test.deepEqual(tz.zonesForCountry("SL"), ["Africa/Abidjan","Africa/Freetown"]);
 		test.deepEqual(tz.zonesForCountry("SM"), ["Europe/Rome","Europe/San_Marino"]);
@@ -813,12 +814,12 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("SS"), ["Africa/Juba"]);
 		test.deepEqual(tz.zonesForCountry("ST"), ["Africa/Sao_Tome"]);
 		test.deepEqual(tz.zonesForCountry("SV"), ["America/El_Salvador"]);
-		test.deepEqual(tz.zonesForCountry("SX"), ["America/Curacao","America/Lower_Princes"]);
+		test.deepEqual(tz.zonesForCountry("SX"), ["America/Lower_Princes","America/Puerto_Rico"]);
 		test.deepEqual(tz.zonesForCountry("SY"), ["Asia/Damascus"]);
 		test.deepEqual(tz.zonesForCountry("SZ"), ["Africa/Johannesburg","Africa/Mbabane"]);
 		test.deepEqual(tz.zonesForCountry("TC"), ["America/Grand_Turk"]);
 		test.deepEqual(tz.zonesForCountry("TD"), ["Africa/Ndjamena"]);
-		test.deepEqual(tz.zonesForCountry("TF"), ["Indian/Kerguelen","Indian/Reunion"]);
+		test.deepEqual(tz.zonesForCountry("TF"), ["Asia/Dubai","Indian/Kerguelen","Indian/Maldives"]);
 		test.deepEqual(tz.zonesForCountry("TG"), ["Africa/Abidjan","Africa/Lome"]);
 		test.deepEqual(tz.zonesForCountry("TH"), ["Asia/Bangkok"]);
 		test.deepEqual(tz.zonesForCountry("TJ"), ["Asia/Dushanbe"]);
@@ -828,24 +829,24 @@ exports.countries = {
 		test.deepEqual(tz.zonesForCountry("TN"), ["Africa/Tunis"]);
 		test.deepEqual(tz.zonesForCountry("TO"), ["Pacific/Tongatapu"]);
 		test.deepEqual(tz.zonesForCountry("TR"), ["Europe/Istanbul"]);
-		test.deepEqual(tz.zonesForCountry("TT"), ["America/Port_of_Spain"]);
-		test.deepEqual(tz.zonesForCountry("TV"), ["Pacific/Funafuti"]);
+		test.deepEqual(tz.zonesForCountry("TT"), ["America/Port_of_Spain","America/Puerto_Rico"]);
+		test.deepEqual(tz.zonesForCountry("TV"), ["Pacific/Funafuti","Pacific/Tarawa"]);
 		test.deepEqual(tz.zonesForCountry("TW"), ["Asia/Taipei"]);
 		test.deepEqual(tz.zonesForCountry("TZ"), ["Africa/Dar_es_Salaam","Africa/Nairobi"]);
-		test.deepEqual(tz.zonesForCountry("UA"), ["Europe/Kiev","Europe/Simferopol","Europe/Uzhgorod","Europe/Zaporozhye"]);
+		test.deepEqual(tz.zonesForCountry("UA"), ["Europe/Kyiv","Europe/Simferopol","Europe/Uzhgorod","Europe/Zaporozhye"]);
 		test.deepEqual(tz.zonesForCountry("UG"), ["Africa/Kampala","Africa/Nairobi"]);
-		test.deepEqual(tz.zonesForCountry("UM"), ["Pacific/Honolulu","Pacific/Midway","Pacific/Pago_Pago","Pacific/Wake"]);
+		test.deepEqual(tz.zonesForCountry("UM"), ["Pacific/Honolulu","Pacific/Midway","Pacific/Pago_Pago","Pacific/Tarawa","Pacific/Wake"]);
 		test.deepEqual(tz.zonesForCountry("US"), ["America/Adak","America/Anchorage","America/Boise","America/Chicago","America/Denver","America/Detroit","America/Indiana/Indianapolis","America/Indiana/Knox","America/Indiana/Marengo","America/Indiana/Petersburg","America/Indiana/Tell_City","America/Indiana/Vevay","America/Indiana/Vincennes","America/Indiana/Winamac","America/Juneau","America/Kentucky/Louisville","America/Kentucky/Monticello","America/Los_Angeles","America/Menominee","America/Metlakatla","America/New_York","America/Nome","America/North_Dakota/Beulah","America/North_Dakota/Center","America/North_Dakota/New_Salem","America/Phoenix","America/Sitka","America/Yakutat","Pacific/Honolulu"]);
 		test.deepEqual(tz.zonesForCountry("UY"), ["America/Montevideo"]);
 		test.deepEqual(tz.zonesForCountry("UZ"), ["Asia/Samarkand","Asia/Tashkent"]);
 		test.deepEqual(tz.zonesForCountry("VA"), ["Europe/Rome","Europe/Vatican"]);
-		test.deepEqual(tz.zonesForCountry("VC"), ["America/Port_of_Spain","America/St_Vincent"]);
+		test.deepEqual(tz.zonesForCountry("VC"), ["America/Puerto_Rico","America/St_Vincent"]);
 		test.deepEqual(tz.zonesForCountry("VE"), ["America/Caracas"]);
-		test.deepEqual(tz.zonesForCountry("VG"), ["America/Port_of_Spain","America/Tortola"]);
-		test.deepEqual(tz.zonesForCountry("VI"), ["America/Port_of_Spain","America/St_Thomas"]);
+		test.deepEqual(tz.zonesForCountry("VG"), ["America/Puerto_Rico","America/Tortola"]);
+		test.deepEqual(tz.zonesForCountry("VI"), ["America/Puerto_Rico","America/St_Thomas"]);
 		test.deepEqual(tz.zonesForCountry("VN"), ["Asia/Bangkok","Asia/Ho_Chi_Minh"]);
 		test.deepEqual(tz.zonesForCountry("VU"), ["Pacific/Efate"]);
-		test.deepEqual(tz.zonesForCountry("WF"), ["Pacific/Wallis"]);
+		test.deepEqual(tz.zonesForCountry("WF"), ["Pacific/Tarawa","Pacific/Wallis"]);
 		test.deepEqual(tz.zonesForCountry("WS"), ["Pacific/Apia"]);
 		test.deepEqual(tz.zonesForCountry("YE"), ["Asia/Aden","Asia/Riyadh"]);
 		test.deepEqual(tz.zonesForCountry("YT"), ["Africa/Nairobi","Indian/Mayotte"]);
