@@ -4,9 +4,13 @@ var helpers = require("../../../helpers/helpers");
 
 exports["America/Argentina/Rio_Gallegos"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("America/Argentina/Rio_Gallegos", { offset: true, expect: "America/Fortaleza" }),
+	"guess:by:offset" : helpers.makeTestGuess("America/Argentina/Rio_Gallegos", { offset: true, expect: "America/Sao_Paulo" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("America/Argentina/Rio_Gallegos", { abbr: true, expect: "America/Fortaleza" }),
+	"guess:by:abbr" : helpers.makeTestGuess("America/Argentina/Rio_Gallegos", { abbr: true, expect: "America/Sao_Paulo" }),
+
+	"1894" : helpers.makeTestYear("America/Argentina/Rio_Gallegos", [
+		["1894-10-31T04:36:52+00:00", "00:20:04", "CMT", 15408 / 60]
+	]),
 
 	"1920" : helpers.makeTestYear("America/Argentina/Rio_Gallegos", [
 		["1920-05-01T04:16:47+00:00", "23:59:59", "CMT", 15408 / 60],
@@ -223,5 +227,9 @@ exports["America/Argentina/Rio_Gallegos"] = {
 	"2007" : helpers.makeTestYear("America/Argentina/Rio_Gallegos", [
 		["2007-12-30T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2007-12-30T03:00:00+00:00", "01:00:00", "-02", 120]
+	]),
+
+	"2008" : helpers.makeTestYear("America/Argentina/Rio_Gallegos", [
+		["2008-03-16T01:59:59+00:00", "23:59:59", "-02", 120]
 	])
 };
\ No newline at end of file
