@@ -8,6 +8,10 @@ exports["America/Bogota"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Bogota", { abbr: true, expect: "America/Lima" }),
 
+	"1884" : helpers.makeTestYear("America/Bogota", [
+		["1884-03-13T04:56:16+00:00", "00:00:00", "BMT", 17776 / 60]
+	]),
+
 	"1914" : helpers.makeTestYear("America/Bogota", [
 		["1914-11-23T04:56:15+00:00", "23:59:59", "BMT", 17776 / 60],
 		["1914-11-23T04:56:16+00:00", "23:56:16", "-05", 300]
@@ -19,7 +23,6 @@ exports["America/Bogota"] = {
 	]),
 
 	"1993" : helpers.makeTestYear("America/Bogota", [
-		["1993-04-04T03:59:59+00:00", "23:59:59", "-04", 240],
-		["1993-04-04T04:00:00+00:00", "23:00:00", "-05", 300]
+		["1993-04-04T03:59:59+00:00", "23:59:59", "-04", 240]
 	])
 };
\ No newline at end of file
