@@ -8,6 +8,10 @@ exports["Singapore"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Singapore", { abbr: true, expect: "Asia/Manila" }),
 
+	"1900" : helpers.makeTestYear("Singapore", [
+		["1900-12-31T17:04:35+00:00", "00:00:00", "SMT", -24925 / 60]
+	]),
+
 	"1905" : helpers.makeTestYear("Singapore", [
 		["1905-05-31T17:04:34+00:00", "23:59:59", "SMT", -24925 / 60],
 		["1905-05-31T17:04:35+00:00", "00:04:35", "+07", -420]
@@ -39,7 +43,6 @@ exports["Singapore"] = {
 	]),
 
 	"1981" : helpers.makeTestYear("Singapore", [
-		["1981-12-31T16:29:59+00:00", "23:59:59", "+0730", -450],
-		["1981-12-31T16:30:00+00:00", "00:30:00", "+08", -480]
+		["1981-12-31T16:29:59+00:00", "23:59:59", "+0730", -450]
 	])
 };
\ No newline at end of file
